@@ -54,4 +54,10 @@ mod iter;
 pub use iter::TopIter;
 
 mod heap;
-pub use heap::TopSet;
\ No newline at end of file
+pub use heap::TopSet;
+
+#[inline]
+pub fn topiter(n: usize) -> TopIter
+{
+    TopIter::new(n)
+}
\ No newline at end of file
